@@ -34,6 +34,8 @@
 #ifndef _RTE_MEMCPY_X86_64_H_
 #define _RTE_MEMCPY_X86_64_H_
 
+#if defined(__x86_64__)
+
 /**
  * @file
  *
@@ -633,4 +635,6 @@ COPY_BLOCK_64_BACK15:
 }
 #endif
 
-#endif /* _RTE_MEMCPY_X86_64_H_ */
\ No newline at end of file
+#endif /* x86_64 */
+
+#endif /* _RTE_MEMCPY_X86_64_H_ */
