@@ -6,14 +6,13 @@ from numpy import linalg as LA
 
 arr = [i for i in range(1,1000)]
 
-@profile
 def doit1(x):
 #    x = [i*i for i in range(1,1000)][0]
     y = 1
 #    w, v = LA.eig(np.diag(arr)) # (1, 2, 3, 4, 5, 6, 7, 8, 9, 10)))
-    x = [i*i for i in range(0,10000)][9999]
-    y1 = [i*i for i in range(0,20000)][19999]
-    z1 = [i for i in range(0,30000)][29999]
+    x = [i*i for i in range(0,100000)][99999]
+    y1 = [i*i for i in range(0,200000)][199999]
+    z1 = [i for i in range(0,300000)][299999]
     z = x * y
 #    z = np.multiply(x, y)
     return z
@@ -54,8 +53,6 @@ def stuff():
             x = doit2(x)
             x = doit3(x)
             x = 1.01
-    if i == 2:
-        return x
     return x
 
 import sys
